@@ -1,20 +1,22 @@
 #pragma once
 
-#include <string>
-#include <vector>
-#include <set>
-#include <map>
+#include <cstdio>
 #include <iostream>
-
-#include <stdio.h>
+#include <map>
+#include <set>
+#include <string>
+#include <type_traits>
+#include <vector>
 
 #include "meta.h"
 #include "util.h"
 
 #include <thrust/limits.h>
+#include <thrust/detail/config.h>
 #include <thrust/detail/integer_traits.h>
-#include <thrust/memory/detail/device_system_resource.h>
-#include <thrust/memory/detail/host_system_resource.h>
+#include <thrust/mr/host_memory_resource.h>
+#include <thrust/mr/device_memory_resource.h>
+#include <thrust/mr/universal_memory_resource.h>
 #include <thrust/mr/allocator.h>
 
 // define some common lists of types
@@ -78,10 +80,13 @@ public:
         fill(0);
     }
 
+    // Allow construction from any integral numeric.
+    template <typename T,
+              typename = typename std::enable_if<std::is_integral<T>::value>::type>
     __host__ __device__
-    custom_numeric(int i)
+    custom_numeric(const T& i)
     {
-        fill(i);
+        fill(static_cast<int>(i));
     }
 
     __host__ __device__
@@ -224,8 +229,7 @@ private:
     }
 };
 
-namespace thrust
-{
+THRUST_NAMESPACE_BEGIN
 
 template <>
 struct numeric_limits<custom_numeric> : numeric_limits<int> {};
@@ -239,7 +243,9 @@ class integer_traits<custom_numeric>
   : public integer_traits_base<int, INT_MIN, INT_MAX>
 {};
 
-}} // namespace thrust::detail
+} // namespace detail
+
+THRUST_NAMESPACE_END
 
 typedef unittest::type_list<char,
                             signed char,
@@ -331,7 +337,7 @@ protected:
   // \param test The UnitTest of interest
   // \param concise Whether or not to suppress output
   // \return true if all is well; false if the tests must be immediately aborted
-  virtual bool post_test_sanity_check(const UnitTest &test, bool concise);
+  virtual bool post_test_smoke_check(const UnitTest &test, bool concise);
 
 public:
   inline virtual ~UnitTestDriver() {};
@@ -359,7 +365,7 @@ class NAME##UnitTest : public UnitTest {                         \
     public:                                                      \
     NAME##UnitTest() : UnitTest(#NAME) {}                        \
     void run(){                                                  \
-            TEST();                                              \
+        TEST();                                                  \
     }                                                            \
 };                                                               \
 NAME##UnitTest NAME##Instance
@@ -388,15 +394,16 @@ void VTEST##Device(void) {                                      \
     VTEST< thrust::device_vector<int,                           \
         thrust::mr::stateless_resource_allocator<int,           \
             thrust::device_memory_resource> > >();              \
-    VTEST< thrust::device_vector<int,                           \
-        thrust::mr::stateless_resource_allocator<int,           \
-            thrust::universal_memory_resource> > >();           \
+}                                                               \
+void VTEST##Universal(void) {                                   \
+    VTEST< thrust::universal_vector<int> >();                   \
     VTEST< thrust::device_vector<int,                           \
         thrust::mr::stateless_resource_allocator<int,           \
             thrust::universal_host_pinned_memory_resource> > >();\
 }                                                               \
 DECLARE_UNITTEST(VTEST##Host);                                  \
-DECLARE_UNITTEST(VTEST##Device);
+DECLARE_UNITTEST(VTEST##Device);                                \
+DECLARE_UNITTEST(VTEST##Universal);
 
 // Same as above, but only for integral types
 #define DECLARE_INTEGRAL_VECTOR_UNITTEST(VTEST)                 \
@@ -410,8 +417,15 @@ void VTEST##Device(void) {                                      \
     VTEST< thrust::device_vector<short> >();                    \
     VTEST< thrust::device_vector<int> >();                      \
 }                                                               \
+void VTEST##Universal(void) {                                   \
+    VTEST< thrust::universal_vector<int> >();                   \
+    VTEST< thrust::device_vector<int,                           \
+        thrust::mr::stateless_resource_allocator<int,           \
+            thrust::universal_host_pinned_memory_resource> > >();\
+}                                                               \
 DECLARE_UNITTEST(VTEST##Host);                                  \
-DECLARE_UNITTEST(VTEST##Device);
+DECLARE_UNITTEST(VTEST##Device);                                \
+DECLARE_UNITTEST(VTEST##Universal);
 
 // Macro to create instances of a test for several data types.
 #define DECLARE_GENERIC_UNITTEST(TEST)                           \
@@ -431,6 +445,22 @@ class TEST##UnitTest : public UnitTest {                         \
 };                                                               \
 TEST##UnitTest TEST##Instance
 
+// Macro to create instances of a test for several array sizes.
+#define DECLARE_SIZED_UNITTEST(TEST)                             \
+class TEST##UnitTest : public UnitTest {                         \
+    public:                                                      \
+    TEST##UnitTest() : UnitTest(#TEST) {}                        \
+    void run()                                                   \
+    {                                                            \
+        std::vector<size_t> sizes = get_test_sizes();            \
+        for(size_t i = 0; i != sizes.size(); ++i)                \
+        {                                                        \
+            TEST(sizes[i]);                                      \
+        }                                                        \
+    }                                                            \
+};                                                               \
+TEST##UnitTest TEST##Instance
+
 // Macro to create instances of a test for several data types and array sizes
 #define DECLARE_VARIABLE_UNITTEST(TEST)                          \
 class TEST##UnitTest : public UnitTest {                         \
