@@ -21,6 +21,8 @@
 
 #pragma once
 
+#include <thrust/detail/config.h>
+
 #include <thrust/detail/algorithm_wrapper.h>
 
 #include <thrust/host_vector.h>
@@ -31,8 +33,7 @@
 
 #include <cassert>
 
-namespace thrust
-{
+THRUST_NAMESPACE_BEGIN
 namespace mr
 {
 
@@ -63,7 +64,7 @@ namespace mr
  *  \tparam Upstream the type of memory resources that will be used for allocating memory blocks
  */
 template<typename Upstream>
-class unsynchronized_pool_resource THRUST_FINAL
+class unsynchronized_pool_resource final
     : public memory_resource<typename Upstream::pointer>,
         private validator<Upstream>
 {
@@ -250,7 +251,7 @@ public:
         m_cached_oversized = oversized_block_descriptor_ptr();
     }
 
-    THRUST_NODISCARD virtual void_ptr do_allocate(std::size_t bytes, std::size_t alignment = THRUST_MR_DEFAULT_ALIGNMENT) THRUST_OVERRIDE
+    THRUST_NODISCARD virtual void_ptr do_allocate(std::size_t bytes, std::size_t alignment = THRUST_MR_DEFAULT_ALIGNMENT) override
     {
         bytes = (std::max)(bytes, m_options.smallest_block_size);
         assert(detail::is_power_of_2(alignment));
@@ -392,10 +393,10 @@ public:
                 )
             );
 
-            chunk_descriptor desc;
-            desc.size = chunk_size;
-            desc.next = m_allocated;
-            *chunk = desc;
+            chunk_descriptor chunk_desc;
+            chunk_desc.size = chunk_size;
+            chunk_desc.next = m_allocated;
+            *chunk = chunk_desc;
             m_allocated = chunk;
 
             for (std::size_t i = 0; i < n; ++i)
@@ -406,9 +407,9 @@ public:
                     )
                 );
 
-                block_descriptor desc;
-                desc.next = bucket.free_list;
-                *block = desc;
+                block_descriptor block_desc;
+                block_desc.next = bucket.free_list;
+                *block = block_desc;
                 bucket.free_list = block;
             }
         }
@@ -423,7 +424,7 @@ public:
         );
     }
 
-    virtual void do_deallocate(void_ptr p, std::size_t n, std::size_t alignment = THRUST_MR_DEFAULT_ALIGNMENT) THRUST_OVERRIDE
+    virtual void do_deallocate(void_ptr p, std::size_t n, std::size_t alignment = THRUST_MR_DEFAULT_ALIGNMENT) override
     {
         n = (std::max)(n, m_options.smallest_block_size);
         assert(detail::is_power_of_2(alignment));
@@ -501,5 +502,5 @@ public:
  */
 
 } // end mr
-} // end thrust
+THRUST_NAMESPACE_END
 
