@@ -32,8 +32,7 @@
 #include <cassert>
 
 
-namespace thrust
-{
+THRUST_NAMESPACE_BEGIN
 
 namespace cuda_cub {
 namespace launcher {
@@ -973,4 +972,4 @@ namespace launcher {
 }    // namespace launcher
 }    // namespace cuda_
 
-} // end namespace thrust
+THRUST_NAMESPACE_END
