@@ -115,9 +115,9 @@ namespace __reduce_by_key {
           mpl::max<
               int,
               1,
-              ((NOMINAL_4B_ITEMS_PER_THREAD * 8) +
+              static_cast<int>(((NOMINAL_4B_ITEMS_PER_THREAD * 8) +
                COMBINED_INPUT_BYTES - 1) /
-                  COMBINED_INPUT_BYTES>::value>::value,
+                  COMBINED_INPUT_BYTES)>::value>::value,
     };
 
     typedef PtxPolicy<128,
