@@ -26,6 +26,8 @@
  ******************************************************************************/
 #pragma once
 
+#include <thrust/detail/config.h>
+
 #if THRUST_DEVICE_COMPILER == THRUST_DEVICE_COMPILER_NVCC
 #include <thrust/detail/cstdint.h>
 #include <thrust/detail/temporary_array.h>
@@ -46,8 +48,7 @@
 #include <thrust/detail/alignment.h>
 #include <thrust/type_traits/is_contiguous_iterator.h>
 
-namespace thrust
-{
+THRUST_NAMESPACE_BEGIN
 namespace cuda_cub {
 
 namespace __merge_sort {
@@ -334,6 +335,7 @@ namespace __merge_sort {
       // Parallel thread block merge sort
       //---------------------------------------------------------------------
 
+      template <bool IS_LAST_TILE>
       THRUST_DEVICE_FUNCTION void
       block_mergesort(int tid,
                       int count,
@@ -343,9 +345,12 @@ namespace __merge_sort {
         using core::uninitialized_array;
         using core::sync_threadblock;
 
-        // stable sort items in a single thread
+        // if first element of thread is in input range, stable sort items
         //
-        stable_odd_even_sort(keys_loc,items_loc);
+        if (!IS_LAST_TILE || ITEMS_PER_THREAD * tid < count)
+        {
+          stable_odd_even_sort(keys_loc, items_loc);
+        }
 
         // each thread has  sorted keys_loc
         // merge sort keys_loc in shared memory
@@ -499,17 +504,17 @@ namespace __merge_sort {
 
         if (IS_LAST_TILE)
         {
-          block_mergesort(tid,
-                          num_remaining,
-                          keys_loc,
-                          items_loc);
+          block_mergesort<IS_LAST_TILE>(tid,
+                                        num_remaining,
+                                        keys_loc,
+                                        items_loc);
         }
         else
         {
-          block_mergesort(tid,
-                          ITEMS_PER_TILE,
-                          keys_loc,
-                          items_loc);
+          block_mergesort<IS_LAST_TILE>(tid,
+                                        ITEMS_PER_TILE,
+                                        keys_loc,
+                                        items_loc);
         }
 
         sync_threadblock();
@@ -1493,10 +1498,13 @@ namespace __radix_sort {
       Key* temp_ptr = reinterpret_cast<Key*>(keys_buffer.d_buffers[1]);
       cuda_cub::copy_n(policy, temp_ptr, keys_count, keys);
     }
-    if (SORT_ITEMS::value && items_buffer.selector != 0)
+    THRUST_IF_CONSTEXPR(SORT_ITEMS::value)
     {
-      Item* temp_ptr = reinterpret_cast<Item*>(items_buffer.d_buffers[1]);
-      cuda_cub::copy_n(policy, temp_ptr, items_count, items);
+      if (items_buffer.selector != 0)
+      {
+        Item *temp_ptr = reinterpret_cast<Item *>(items_buffer.d_buffers[1]);
+        cuda_cub::copy_n(policy, temp_ptr, items_count, items);
+      }
     }
   }
 }    // __radix_sort
@@ -1748,5 +1756,5 @@ stable_sort_by_key(
 
 
 }    // namespace cuda_cub
-} // end namespace thrust
+THRUST_NAMESPACE_END
 #endif
