@@ -21,8 +21,7 @@
 #include <thrust/detail/type_traits.h>
 #include <thrust/detail/execution_policy.h>
 
-namespace thrust
-{
+THRUST_NAMESPACE_BEGIN
 
 /// Unary metafunction that is \c true if \c T is an \a ExecutionPolicy and
 /// \c false otherwise.
@@ -45,6 +44,6 @@ template <typename T>
 constexpr bool is_execution_policy_v = is_execution_policy<T>::value;
 #endif
 
-} // end namespace thrust
+THRUST_NAMESPACE_END
 
 
